#include <qapplication.h>
#include <qpushbutton.h>
#include <qlabel.h>
#include <qfont.h>
#include <qlayout.h>
#include <qstring.h>
#include <qcombobox.h>
#include <qlistbox.h>
#include <qhbox.h>
#include <qpen.h>
#include <qnamespace.h>


#include "painter.h"
#include "canvas.h"


Painter::Painter( QWidget *parent, const char *name )
        : QWidget( parent, name )
{
    setMinimumSize( 500, 355 );

    QPushButton *quit = new QPushButton( "Quit", this, "quit" );
    quit->setFont( QFont( "Times", 14, QFont::Bold ) );
    connect( quit, SIGNAL(clicked()), qApp, SLOT(quit()) );

    canvas = new Canvas( this, "cone" );
	connect( canvas, SIGNAL(changePos()), SLOT(newPosition( )) );
	connect( canvas, SIGNAL(changeSize()), SLOT(newSize( )) );

    myinit = new QPushButton( "Init", this, "myinit" );
    myinit->setFont( QFont( "Times", 14, QFont::Bold ) );
    connect( myinit, SIGNAL(clicked()), canvas, SLOT(initscreen()) );

    stop = new QPushButton( "Stop", this, "stop" );
    stop->setFont( QFont( "Times", 14, QFont::Bold ) );
    connect( stop, SIGNAL(clicked()), canvas, SLOT(stop()) );
    
    
    escena1 = new QPushButton( "Rota escena1", this, "escena1" );
    escena1->setFont( QFont( "Times", 14, QFont::Bold ) );
    connect( escena1, SIGNAL(clicked()), canvas, SLOT(rota1()) );
    
    escena2 = new QPushButton( "Rota escena2", this, "escena2" );
    escena2->setFont( QFont( "Times", 14, QFont::Bold ) );
    connect( escena2, SIGNAL(clicked()), canvas, SLOT(rota2()) );

    QGridLayout *grid = new QGridLayout( this, 1, 2, 5 ); //2x2, 5 pixel border
    grid->addWidget( canvas, 0, 1 );
    grid->setColStretch( 1, 10 );


	shaded = new QComboBox( this, "shades" );
    shaded->insertItem( "FLAT" );
    shaded->insertItem( "SMOOTH" );
	connect( shaded, SIGNAL(activated(int)), canvas, SLOT(shade_model(int)) );

    messpos = new QLabel( this, "messagepos"  );
    messpos->setMaximumHeight( 20 );
    messpos->setFrameStyle( QFrame::WinPanel | QFrame::Sunken );
    messpos->setBackgroundColor( messpos->colorGroup().base() );
    messpos->setAlignment( AlignCenter );

    messize = new QLabel( this, "message_size"  );
    messize->setMaximumHeight( 20 );
    messize->setFrameStyle( QFrame::WinPanel | QFrame::Sunken );
    messize->setBackgroundColor( messpos->colorGroup().base() );
    messize->setAlignment( AlignCenter );

    // Labels for the new displays...
    visorMouse = new QLabel(this, "message_size"  );
    visorMouse->setMaximumHeight( 20 );
    visorMouse->setText("Mouse:");
    visorMouse->setAlignment( AlignCenter );

    // Labels for the new displays...
    visorTama = new QLabel(this, "message_size"  );
    visorTama->setMaximumHeight( 20 );
    visorTama->setText("Tamao:");
    visorTama->setAlignment( AlignCenter );

	QVBoxLayout *leftBox = new QVBoxLayout;
	grid->addLayout( leftBox, 0, 0 );
	leftBox->addWidget( quit );
	leftBox->addWidget( myinit );
	leftBox->addWidget( stop );
	leftBox->addWidget( escena1 );
	leftBox->addWidget( escena2 );
	leftBox->addWidget( shaded );
	leftBox->addWidget(visorMouse);
	leftBox->addWidget( messpos );
	leftBox->addWidget(visorTama);
	leftBox->addWidget( messize );
}

void Painter::newPosition( )
{
	int mx, my;

	canvas->getPosition( &mx, &my );

    QString s;
	messpos->setText( s.sprintf("%d,%d", mx, my ) );
}

void Painter::newSize( )
{
	int mx, my;

	canvas->getSize( &mx, &my );

    QString s;
	messize->setText( s.sprintf("%d,%d", mx, my ) );
}

